==> hibiscus.js-1.2.1.tgz: package/common/services/update-host-class.service.js <==
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Injectable, Renderer2 } from '@angular/core';
var UpdateHostClassService = /** @class */ (function () {
    function UpdateHostClassService(renderer) {
        this.renderer = renderer;
        this.classMap = {};
    }
    UpdateHostClassService.prototype.updateHostClass = function (el, classMap) {
        this.removeClass(el, this.classMap, this.renderer);
        this.classMap = __assign({}, classMap);
        this.addClass(el, this.classMap, this.renderer);
    };
    UpdateHostClassService.prototype.removeClass = function (el, classMap, renderer) {
        for (var i in classMap) {
            if (classMap.hasOwnProperty(i)) {
                renderer.removeClass(el, i);
            }
        }
    };
    UpdateHostClassService.prototype.addClass = function (el, classMap, renderer) {
        for (var i in classMap) {
            if (classMap.hasOwnProperty(i)) {
                if (classMap[i]) {
                    renderer.addClass(el, i);
                }
            }
        }
    };
    UpdateHostClassService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    UpdateHostClassService.ctorParameters = function () { return [
        { type: Renderer2, },
    ]; };
    return UpdateHostClassService;
}());
export { UpdateHostClassService };

==> hibiscus.js-1.2.3.tgz: package/common/services/update-host-class.service.js <==
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Injectable, Renderer2 } from '@angular/core';
var UpdateHostClassService = (function () {
    function UpdateHostClassService(renderer) {
        this.renderer = renderer;
        this.classMap = {};
    }
    UpdateHostClassService.prototype.updateHostClass = function (el, classMap) {
        this.removeClass(el, this.classMap, this.renderer);
        this.classMap = __assign({}, classMap);
        this.addClass(el, this.classMap, this.renderer);
    };
    UpdateHostClassService.prototype.removeClass = function (el, classMap, renderer) {
        for (var i in classMap) {
            if (classMap.hasOwnProperty(i)) {
                renderer.removeClass(el, i);
            }
        }
    };
    UpdateHostClassService.prototype.addClass = function (el, classMap, renderer) {
        for (var i in classMap) {
            if (classMap.hasOwnProperty(i)) {
                if (classMap[i]) {
                    renderer.addClass(el, i);
                }
            }
        }
    };
    UpdateHostClassService.decorators = [
        { type: Injectable },
    ];
    UpdateHostClassService.ctorParameters = function () { return [
        { type: Renderer2, },
    ]; };
    return UpdateHostClassService;
}());
export { UpdateHostClassService };
